@@ -30,14 +30,16 @@
 #define PRINTERVAL 20 /** Print Progress Interval (seconds) */
 #define CRASHFILE "savedstate.sav"
 #define VERSION_MAJOR 0
-#define VERSION_MINOR 2
+#define VERSION_MINOR 3
 
+/** alarmInterrupt is used to print out the progress at specific intervals */
 static void
 alarmInterrupt() {
   if(!printProgress())
     alarm(PRINTERVAL);
 }
 
+/** autoSave is used to save down the current state when interrupted */
 __attribute__ ((noreturn)) static void
 autoSave(int sig) {
   FILE *file;
@@ -55,6 +57,7 @@ autoSave(int sig) {
   exit(sig);
 }
 
+/** print some help for the user */
 static void
 printHelp(char *progname) {
   printf("Usage: %s -f filename [OPTIONS]\n"
@@ -75,7 +78,7 @@ printHelp(char *progname) {
 
 int
 main(int argc, char** argv) {
-  int c, option_index, ret = 0, minpw = 0, maxpw = 32;
+  int ret = 0, minpw = 0, maxpw = 32;
   struct sigaction act1, act2;
   FILE *file = NULL, *wordlist = NULL;
   bool recovery = false, quiet = false, work_with_user = true;
@@ -83,12 +86,9 @@ main(int argc, char** argv) {
   char *charset = NULL, *inputfile = NULL, *wordlistfile = NULL;
   EncData *e;
 
-  if(argc < 2) {
-    printHelp(argv[0]);
-    exit(1);
-  }
-  
+  /** Parse arguments */
   while(true) {
+    int c, option_index;
     static struct option long_options[] = {
       {"charset",  required_argument, 0, 'c'},
       {"file",     required_argument, 0, 'f'},
@@ -106,7 +106,7 @@ main(int argc, char** argv) {
     option_index = 0;
      
     c = getopt_long(argc, argv, "c:f:l:m:n:op:quw:v",
-		    long_options, &option_index);
+			long_options, &option_index);
     
     /* Detect the end of the options. */
     if(c == -1)
@@ -176,44 +176,54 @@ main(int argc, char** argv) {
 
     default:
       printHelp(argv[0]);
-      exit(1);
+      ret = 1;
+      goto out3;
     }
   }
-  int i = optind;
-  if(i > 0) {
-    if(!inputfile)
-      inputfile = strdup(argv[i++]);
-    if(i < argc && !wordlistfile)
-      wordlistfile = strdup(argv[i++]);
-    if(i < argc)
-      while(i<argc) {
-	fprintf(stderr,"Non-option argument %s\n", argv[i++]);
-      }
-  }
 
+  /** If there are any unhandled arguments and the filename and/or wordlist is
+      not set: try to match the first as the filename and the second as 
+      wordlist.
+  */
+  {
+    int i = optind;
+    if(i > 0) {
+      if(i < argc && !inputfile)
+	inputfile = strdup(argv[i++]);
+      if(i < argc && !wordlistfile)
+	wordlistfile = strdup(argv[i++]);
+      if(i < argc)
+	while(i<argc) {
+	  fprintf(stderr,"Non-option argument %s\n", argv[i++]);
+	}
+    }
+  }
 
   if(!inputfile || minpw < 0 || maxpw < 0) {
     printHelp(argv[0]);
-    exit(1);
+    ret = 1;
+    goto out3;
   }
 
   if((file = fopen(inputfile, "r")) == 0) {
     fprintf(stderr,"Error: file %s not found\n", inputfile);
-    exit(2);
+    ret = 2;
+    goto out3;
   }
 
   e = calloc(1,sizeof(EncData));
-    
+
   if(recovery) {
     if(wordlistfile) {
       free(wordlistfile);
       wordlistfile = NULL;
     }
     loadState(file, e, &wordlistfile, &work_with_user);
+
     if(!quiet)
       printf("Loaded state for %s\n", inputfile);
   }
-  else{
+  else { /** !recovery */
     if(!openPDF(file,e)) {
       fprintf(stderr, "Error: Not a valid PDF\n");
       ret = 3;
@@ -233,12 +243,11 @@ main(int argc, char** argv) {
       ret = 4;
       goto out1;
     }
-
-    if(fclose(file)) {
-      fprintf(stderr, "Error: closing file %s\n", inputfile);
-    }
   }
 
+  if(fclose(file)) {
+    fprintf(stderr, "Error: closing file %s\n", inputfile);
+  }
 
   if(wordlistfile) {
     if((wordlist = fopen(wordlistfile, "r")) == 0) {
@@ -262,6 +271,8 @@ main(int argc, char** argv) {
     alarm(PRINTERVAL);
   }
 
+
+  /** Try to initialize the cracking-engine */
   if(!initPDFCrack(e, userpassword, work_with_user, wordlistfile,
 		   wordlistfile?Wordlist:Generative, wordlist, charset, 
 		   (unsigned int)minpw, (unsigned int)maxpw)) {
@@ -270,8 +281,12 @@ main(int argc, char** argv) {
     ret = 7;
     goto out2;
   }
+
+  /** Do the actual crunching */
   runCrack();
 
+
+  /** cleanup */
   cleanPDFCrack();
   freeEncData(e);
 
@@ -293,6 +308,7 @@ main(int argc, char** argv) {
     fprintf(stderr, "Error: closing file %s\n", inputfile);
  out2:
   freeEncData(e);
+ out3:
   if(inputfile)
     free(inputfile);
   if(charset)
