@@ -23,6 +23,9 @@
 #define likely(x)       __builtin_expect((x),1)
 #define unlikely(x)     __builtin_expect((x),0)
 
+/** Seems to faster to do a memcpy of this on my machine than to create 
+    the array with a loop
+*/
 static const uint8_t
 initial_state[256] = {
     0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b,
@@ -48,36 +51,6 @@ initial_state[256] = {
     0xf0, 0xf1, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xfb,
     0xfc, 0xfd, 0xfe, 0xff};
 
-/**
-void
-rc4Decrypt(const uint8_t *key, const unsigned int keylength,
-	   const uint8_t *bs, const unsigned int len, uint8_t *out) {
-  uint8_t state[256];
-  register unsigned int i,j;
-  register uint8_t tmp;
-
-  memcpy(state, initial_state, 256);
-
-  j = 0;
-  for(i=0;i<256;++i) {
-    tmp = state[i];
-    j = (j+ tmp + key[i % keylength]) & 0xff;
-    state[i] = state[j];
-    state[j] = tmp;
-  }
-
-  j = 0;
-  for(i=1;i<=len;++i) {
-    tmp = state[i];
-    j = (j+tmp) & 0xff;
-    state[i] = state[j];
-    state[j] = tmp;
-
-    out[i-1] = bs[i-1]^state[(state[i]+tmp) & 0xff];
-  }
-}
-*/
-
 #define key_pass(n) {				\
     tmp = state[++i];				\
     j = (j+ tmp + key[n]) & 0xff;		\
@@ -85,6 +58,7 @@ rc4Decrypt(const uint8_t *key, const unsigned int keylength,
     state[j] = tmp;				\
 }
 
+/** Do rc4-decrypt with key on bs of length len and compare it to match */
 __attribute__ ((pure)) bool
 rc4Match40b(const uint8_t *key, const uint8_t *bs,
 	    const unsigned int len, const uint8_t *match) {
@@ -134,6 +108,9 @@ rc4Match40b(const uint8_t *key, const uint8_t *bs,
 static void(*rc4d)(const uint8_t *key, const uint8_t *bs,
 		   const unsigned int len, uint8_t *out) = NULL;
 
+/** Do 40-bit rc4-decrypt with key on bs of length len and 
+    put the result in out 
+*/
 static void
 rc4Decrypt40b(const uint8_t *key, const uint8_t *bs,
 	      const unsigned int len, uint8_t *out) {
@@ -173,6 +150,9 @@ rc4Decrypt40b(const uint8_t *key, const uint8_t *bs,
   }
 }
 
+/** Do 128-bit rc4-decrypt with key on bs of length len and 
+    put the result in out 
+*/
 static void
 rc4Decrypt128b(const uint8_t *key, const uint8_t *bs,
 	       const unsigned int len, uint8_t *out) {
@@ -219,12 +199,14 @@ rc4Decrypt128b(const uint8_t *key, const uint8_t *bs,
   }
 }
 
+/** Just a wrapper for the function optimized for a specific length */
 void
 rc4Decrypt(const uint8_t *key, const uint8_t *bs,
 	   const unsigned int len, uint8_t *out) {
   rc4d(key, bs, len, out);
 }
 
+/** sets which function the wrapper should call */
 __attribute__ ((pure)) bool
 setrc4DecryptMethod(const unsigned int length) {
   if(length == 128)
